Datamaxi

Trait Datamaxi 

pub trait Datamaxi {
    // Required methods
    fn new(api_key: String) -> Self;
    fn new_with_base_url(api_key: String, base_url: String) -> Self;
}
A trait that defines the required methods for interacting with the Datamaxi+ API.

Required Methods

fn new(api_key: String) -> Self

Creates a new instance of the implementing type using the provided API key.

fn new_with_base_url(api_key: String, base_url: String) -> Self

Creates a new instance of the implementing type using the provided API key and base URL.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Datamaxi for Candle

Implements the Datamaxi trait for Candle, providing methods to create new instances of Candle with or without a custom base URL.

Source

impl Datamaxi for datamaxi::dex::Dex

Implements the Datamaxi trait for Dex, providing methods to create new instances of Dex with or without a custom base URL.

Source

impl Datamaxi for Announcements

Source

impl Datamaxi for CexCandle

Source

impl Datamaxi for CexSymbol

Source

impl Datamaxi for datamaxi::generated::Dex

Source

impl Datamaxi for Forex

Source

impl Datamaxi for FundingRate

Source

impl Datamaxi for IndexPrice

Source

impl Datamaxi for Liquidation

Source

impl Datamaxi for Listing

Source

impl Datamaxi for MarginBorrow

Source

impl Datamaxi for NaverTrend

Source

impl Datamaxi for OpenInterest

Source

impl Datamaxi for Premium

Source

impl Datamaxi for Telegram

Source

impl Datamaxi for Ticker

Source

impl Datamaxi for Token

Source

impl Datamaxi for TradingFees

Source

impl Datamaxi for WalletStatus