pub trait Datamaxi {
// Required methods
fn new(api_key: String) -> Self;
fn new_with_base_url(api_key: String, base_url: String) -> Self;
}Expand description
A trait that defines the required methods for interacting with the Datamaxi+ API.
Required Methods
Sourcefn new(api_key: String) -> Self
fn new(api_key: String) -> Self
Creates a new instance of the implementing type using the provided API key.
Sourcefn new_with_base_url(api_key: String, base_url: String) -> Self
fn new_with_base_url(api_key: String, base_url: String) -> Self
Creates a new instance of the implementing type using the provided API key and base URL.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
impl Datamaxi for Candle
Implements the Datamaxi trait for Candle, providing methods
to create new instances of Candle with or without a custom base URL.
impl Datamaxi for datamaxi::dex::Dex
Implements the Datamaxi trait for Dex, providing methods
to create new instances of Dex with or without a custom base URL.